@@ -136,10 +136,9 @@ class InferArguments:
     dequalify: bool = False
     enable_memory_profiling: bool = False
     enable_profiling: bool = False
-    interprocedural: bool = False
     log_identifier: Optional[str] = None
     logging_sections: Optional[str] = None
-    no_future_annotations: bool = False
+    use_future_annotations: bool = False
     in_place: bool = False
     paths_to_modify: Optional[Set[Path]] = None
     print_only: bool = False
