@@ -4,21 +4,65 @@
 # LICENSE file in the root directory of this source tree.
 
 
+import dataclasses
 import json
-from typing import List, Optional
+import os
+from pathlib import Path
+from typing import List, Optional, Sequence, Dict, Any
 
 from typing_extensions import Final
 
 from .. import command_arguments, log
 from ..analysis_directory import AnalysisDirectory, resolve_analysis_directory
 from ..configuration import Configuration
-from ..error import print_errors
-from .check import Check
+from ..error import ModelVerificationError, print_errors
 from .command import ClientException, ExitCode
-from .validate_models import ValidateModels
+from .reporting import Reporting
 
 
-class Analyze(Check):
+def _relativize_error(
+    configuration: Configuration,
+    relative_root: str,
+    error: ModelVerificationError,
+    original_directory: str,
+) -> ModelVerificationError:
+    if error.path is None:
+        return error
+
+    path = os.path.realpath(os.path.join(relative_root, error.path))
+    # If relative paths don't make sense, keep the absolute path around.
+    if not path.startswith(configuration.project_root) or not os.path.exists(path):
+        return error
+
+    # Relativize path to user's cwd.
+    relative_path = os.path.relpath(path, original_directory)
+    return dataclasses.replace(error, path=relative_path)
+
+
+def parse_errors(
+    json_result: Dict[str, Any],
+    configuration: Configuration,
+    analysis_directory: AnalysisDirectory,
+    original_directory: str,
+) -> Sequence[ModelVerificationError]:
+    if "errors" not in json_result:
+        return []
+    analysis_root = os.path.realpath(analysis_directory.get_root())
+    return sorted(
+        (
+            _relativize_error(
+                configuration,
+                analysis_root,
+                ModelVerificationError.from_json(error_json),
+                original_directory,
+            )
+            for error_json in json_result["errors"]
+        ),
+        key=lambda error: (error.path or Path(), error.line, error.code),
+    )
+
+
+class Analyze(Reporting):
     NAME = "analyze"
 
     def __init__(
@@ -79,6 +123,39 @@ class Analyze(Check):
 
     def _flags(self) -> List[str]:
         flags = super()._flags()
+        filter_directories = self._get_directories_to_analyze()
+        filter_directories.update(
+            set(self._configuration.get_existent_do_not_ignore_errors_in_paths())
+        )
+        if len(filter_directories):
+            flags.extend(["-filter-directories", ";".join(sorted(filter_directories))])
+        flags.extend(["-workers", str(self._configuration.get_number_of_workers())])
+
+        search_path = [
+            search_path.command_line_argument()
+            for search_path in (
+                self._configuration.expand_and_get_existent_search_paths()
+            )
+        ]
+
+        ignore_all_errors_paths = (
+            self._configuration.get_existent_ignore_all_errors_paths()
+        )
+        if len(ignore_all_errors_paths):
+            flags.extend(
+                ["-ignore-all-errors", ";".join(sorted(ignore_all_errors_paths))]
+            )
+        if search_path:
+            flags.extend(["-search-path", ",".join(search_path)])
+        excludes = self._configuration.excludes
+        for exclude in excludes:
+            flags.extend(["-exclude", exclude])
+        extensions = [
+            extension.command_line_argument()
+            for extension in self._configuration.extensions
+        ]
+        for extension in extensions:
+            flags.extend(["-extension", extension])
         flags.extend(["-analysis", self._analysis])
         if self._taint_models_path:
             for path in self._taint_models_path:
@@ -122,7 +199,7 @@ class Analyze(Check):
         result.check()
 
         try:
-            errors = ValidateModels.parse_errors(
+            errors = parse_errors(
                 json.loads(result.output),
                 self._configuration,
                 self._analysis_directory,
