@@ -9,7 +9,6 @@ import copy
 import io
 import logging
 import logging.handlers
-import os
 import re
 import subprocess
 import sys
@@ -69,6 +68,7 @@ class SectionFormatter(logging.Formatter):
         return re.sub(r"DEBUG \[(.*)\]", r"\1", formatted)
 
 
+# pyre-fixme[24]: Generic type `logging.StreamHandler` expects 1 type parameter.
 class TimedStreamHandler(logging.StreamHandler):
     THRESHOLD: float = 0.5
     LINE_BREAKING_LEVELS: Sequence[str] = ["ERROR", "WARNING", "SUCCESS"]
@@ -203,22 +203,19 @@ def initialize(noninteractive: bool) -> None:
     logging.basicConfig(level=logging.DEBUG, handlers=[stream_handler])
 
 
-def start_logging_to_directory(noninteractive: bool, log_directory: str) -> None:
-    if not noninteractive and log_directory is not None:
-        if not os.path.exists(log_directory):
-            os.makedirs(log_directory)
-        handler = logging.handlers.RotatingFileHandler(
-            os.path.join(log_directory, "pyre.stderr"),
-            mode="a",
-            # Keep at most 5 log files on disk
-            backupCount=4,
-            # Limit the size of each log file to 10MB
-            maxBytes=10 * 1000 * 1000,
-        )
-        handler.setFormatter(SectionFormatter())
-        handler.setLevel(logging.DEBUG)
-        logger = logging.getLogger()
-        logger.addHandler(handler)
+def enable_file_logging(log_file: Path) -> None:
+    handler = logging.handlers.RotatingFileHandler(
+        str(log_file),
+        mode="a",
+        # Keep at most 5 log files on disk
+        backupCount=4,
+        # Limit the size of each log file to 10MB
+        maxBytes=10 * 1000 * 1000,
+    )
+    handler.setFormatter(SectionFormatter())
+    handler.setLevel(logging.DEBUG)
+    logger = logging.getLogger()
+    logger.addHandler(handler)
 
 
 def cleanup() -> None:
